"use client"

import { motion } from "framer-motion"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Sparkles, MessageSquareText, Layers } from "lucide-react"

export default function Services() {
  const services = [
    {
      icon: <Sparkles className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "Yapay Zeka Destekli Dijital Pazarlama",
      description:
        "SEO optimizasyonu, içerik üretimi ve reklam yönetiminde yapay zeka teknolojisinden yararlanarak dijital pazarlama stratejilerinizi güçlendiriyoruz.",
      details: [
        "Akıllı algoritmalarla SEO stratejisi ve anahtar kelime analizi",
        "Yapay zeka ile yüksek kaliteli içerik üretimi",
        "AI destekli reklam kampanyaları ve hedefleme optimizasyonu",
      ],
    },
    {
      icon: <MessageSquareText className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "AI Chatbot ve Müşteri Hizmetleri Otomasyonu",
      description:
        "7/24 aktif yapay zeka sohbet botlarımız ve sanal asistanlarımız ile müşteri iletişimini yeni bir düzeye taşıyın.",
      details: [
        "Doğal dil işleme ile insan benzeri iletişim",
        "Sıkça sorulan soruları anında yanıtlama",
        "Müşteri temsilcisi yükünü azaltma ve maliyet tasarrufu",
      ],
    },
    {
      icon: <Layers className="h-10 w-10 text-amber-400 golden-neon-glow" />,
      title: "Sektör Bazlı Yapay Zeka Çözümleri",
      description: "İşletmenizin sektörüne özel yapay zeka çözümleri geliştiriyoruz.",
      details: [
        "Restoranlar için AI garson sistemleri",
        "Ofisler için AI sekreter uygulamaları",
        "Sağlık alanında AI terapist ve asistanlar",
      ],
    },
  ]

  const containerVariants = {
    hidden: { opacity: 0 },
    visible: {
      opacity: 1,
      transition: {
        staggerChildren: 0.2,
      },
    },
  }

  const itemVariants = {
    hidden: { opacity: 0, y: 20 },
    visible: {
      opacity: 1,
      y: 0,
      transition: { duration: 0.5 },
    },
  }

  return (
    <section className="py-20 relative" id="services">
      <div className="absolute inset-0 animated-gradient-bg z-0"></div>

      <div className="container relative z-10">
        <div className="text-center mb-16">
          <h2 className="text-4xl font-bold mb-4 golden-text">Hizmetlerimiz</h2>
          <p className="text-muted-foreground max-w-2xl mx-auto">
            Anamur AI olarak, yapay zeka desteğiyle zenginleştirilmiş geniş bir dijital pazarlama hizmetleri yelpazesi
            sunuyoruz.
          </p>
        </div>

        <motion.div
          className="grid md:grid-cols-3 gap-8"
          variants={containerVariants}
          initial="hidden"
          whileInView="visible"
          viewport={{ once: true, amount: 0.2 }}
        >
          {services.map((service, index) => (
            <motion.div key={index} variants={itemVariants}>
              <Card className="h-full glass-card hover:neon-border transition-all duration-300">
                <CardHeader>
                  <div className="mb-4">{service.icon}</div>
                  <CardTitle className="text-xl text-white">{service.title}</CardTitle>
                  <CardDescription className="text-muted-foreground">{service.description}</CardDescription>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-2">
                    {service.details.map((detail, i) => (
                      <li key={i} className="flex items-start">
                        <span className="text-primary mr-2">•</span>
                        <span className="text-gray-300">{detail}</span>
                      </li>
                    ))}
                  </ul>
                </CardContent>
              </Card>
            </motion.div>
          ))}
        </motion.div>
      </div>
    </section>
  )
}

